summaryrefslogtreecommitdiffstats
path: root/usr.sbin/ppp/main.c
diff options
context:
space:
mode:
authorbrian <brian@FreeBSD.org>2000-03-14 01:47:07 +0000
committerbrian <brian@FreeBSD.org>2000-03-14 01:47:07 +0000
commit11898ff77cba732f0cb7e93a7669c9da0a192285 (patch)
tree846a879f6cfb62c32f99358710612e9c7c751c0a /usr.sbin/ppp/main.c
parentbe63b172324c0cae239dcea5913686e4fe3aa28f (diff)
downloadFreeBSD-src-11898ff77cba732f0cb7e93a7669c9da0a192285.zip
FreeBSD-src-11898ff77cba732f0cb7e93a7669c9da0a192285.tar.gz
Correct some typos introduced in the descriptor -> fdescriptor change.
Diffstat (limited to 'usr.sbin/ppp/main.c')
-rw-r--r--usr.sbin/ppp/main.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/usr.sbin/ppp/main.c b/usr.sbin/ppp/main.c
index 336ed3e..6bcfdce 100644
--- a/usr.sbin/ppp/main.c
+++ b/usr.sbin/ppp/main.c
@@ -583,8 +583,8 @@ DoLoop(struct bundle *bundle)
for (i = 0; i <= nfds; i++)
if (FD_ISSET(i, &efds)) {
- log_Printf(LogPHASE, "Exception detected on fdescriptor %d\n", i);
- /* We deal gracefully with link fdescriptor exceptions */
+ log_Printf(LogPHASE, "Exception detected on descriptor %d\n", i);
+ /* We deal gracefully with link descriptor exceptions */
if (!bundle_Exception(bundle, i)) {
log_Printf(LogERROR, "Exception cannot be handled !\n");
break;
OpenPOWER on IntegriCloud